@@ -202,11 +202,6 @@ print.trellis <-
              prefix = NULL,
              ...)
 {
-    panel.error <-
-        if (is.function(panel.error)) panel.error 
-        else if (is.character(panel.error)) get(panel.error)
-        else eval(panel.error)
-
     ## save the current object, if so requested.  This used to be done
     ## at the end, so that it wouldn't happen if there were errors
     ## during printing.  However, doing this now will allow things
@@ -271,6 +266,11 @@ print.trellis <-
         if ("prefix"       %in% supplied && missing(prefix))       prefix       <- x$plot.args$prefix
     }
 
+    panel.error <-
+        if (is.function(panel.error)) panel.error 
+        else if (is.character(panel.error)) get(panel.error)
+        else eval(panel.error)
+
     bg <- trellis.par.get("background")$col
     new <-  newpage && !lattice.getStatus("print.more") && is.null(draw.in)
     if (!is.null(draw.in))
@@ -692,7 +692,6 @@ print.trellis <-
                                   gp = global.gpar,
                                   name = trellis.vpname("toplevel")))
 
-
             if (!is.null(main))
             {
                 drawInViewport(main,
@@ -1057,7 +1056,7 @@ print.trellis <-
 
 
                         if (!("..." %in% names(formals(panel))))
-                            pargs <- pargs[names(formals(panel))]
+                            pargs <- pargs[intersect(names(pargs), names(formals(panel)))]
                         tryCatch(do.call("panel", pargs),
                                  error = function(e) panel.error(e))
 
